NaMaster: nmt_binning_scheme Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_binning_scheme Struct Reference

Full-sky bandpowers. More...

`#include <namaster.h>`

## Data Fields
int | n_bands
| Number of bandpowers. More...
int * | nell_list
| Number of multipoles belonging to each bandpower. More...
int ** | ell_list
| List of multipoles in each bandpowers. More...
flouble ** | w_list
| List of weights associated to each multipole in `ell_list`. More...
flouble ** | f_ell
| Multiplicative ell factor. More...
int | ell_max
| Maximum multipole included. More...

## Detailed Description

Full-sky bandpowers.

This structure defines bandpowers for full-sky power spectra. Although a given multipole ell can only contribute to one bandpower, the distribution of ells per bandpower and their relative weights is left completely free.

## Field Documentation

int** nmt_binning_scheme::ell_list

List of multipoles in each bandpowers.

int nmt_binning_scheme::ell_max

Maximum multipole included.

flouble** nmt_binning_scheme::f_ell

Multiplicative ell factor.

int nmt_binning_scheme::n_bands

Number of bandpowers.

int* nmt_binning_scheme::nell_list

Number of multipoles belonging to each bandpower.

flouble** nmt_binning_scheme::w_list

List of weights associated to each multipole in `ell_list`.

The documentation for this struct was generated from the following file:

- namaster.h